@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 """vega FYI 
 
-    @author: zhangxing
+    @author: vegaviazhang
     @file:demo_test.py
     @time:2021/12/28
 """
@@ -21,11 +21,11 @@ def main():
 
     # 1.最大前向匹配
     origin_text = "糖尿病一型糖尿病糖尿病二型高血压焦虑情绪慢性肾脏疾病1期"
-    match_list = vega_trie.match_all_longest_item(origin_text)
+    match_list = vega_trie.get_match_words(origin_text)
     print(match_list)
 
     # 2.判断一个词是否在字典树中
-    print(vega_trie.is_in("abc"))
+    print(vega_trie.check_exist("abc"))
     # (False, None)
 
 
